# Generated by ariadne-codegen
# Source: operations.graphql

from typing import List

from pydantic import Field

from .base_model import BaseModel
from .fragments import CreditLedgerFragment, PageInfoFragment


class GetCreditLedger(BaseModel):
    credits_ledger: "GetCreditLedgerCreditsLedger" = Field(alias="creditsLedger")


class GetCreditLedgerCreditsLedger(BaseModel):
    page_info: "GetCreditLedgerCreditsLedgerPageInfo" = Field(alias="pageInfo")
    edges: List["GetCreditLedgerCreditsLedgerEdges"]
    total_count: int = Field(alias="totalCount")


class GetCreditLedgerCreditsLedgerPageInfo(PageInfoFragment):
    pass


class GetCreditLedgerCreditsLedgerEdges(BaseModel):
    node: "GetCreditLedgerCreditsLedgerEdgesNode"
    cursor: str


class GetCreditLedgerCreditsLedgerEdgesNode(CreditLedgerFragment):
    pass


GetCreditLedger.model_rebuild()
GetCreditLedgerCreditsLedger.model_rebuild()
GetCreditLedgerCreditsLedgerEdges.model_rebuild()
