# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import CreditGrantFragment


class GrantCredits(BaseModel):
    create_credit_grant: "GrantCreditsCreateCreditGrant" = Field(
        alias="createCreditGrant"
    )


class GrantCreditsCreateCreditGrant(CreditGrantFragment):
    pass


GrantCredits.model_rebuild()
